@@ -59,14 +59,22 @@ add_logging_level("trace", TRACE)
 logzero.loglevel(DEFAULT_LEVEL)
 logzero.formatter(logzero.LogFormatter(fmt=DEFAULT_MESSAGE_FORMAT, datefmt=DEFAULT_DATE_FORMAT, colors=DEFAULT_COLORS))
 path = pathlib.Path(__main__.__file__)
-logzero.logfile(
-    filename="_input_.log" if path.stem == "<input>" else path.with_suffix(".log"),
-    formatter=logzero.LogFormatter(fmt=DEFAULT_FILE_FORMAT, datefmt=DEFAULT_DATE_FORMAT),
-    maxBytes=DEFAULT_FILE_SIZE,
-    backupCount=DEFAULT_BACKUP_COUNT,
-    encoding="utf-8",
-    loglevel=DEFAULT_LEVEL,
-)
+if path.stem == '__main__':
+    path = path.parent
+
+
+def _default_file():
+    logzero.logfile(
+        filename="_input_.log" if path.stem == "<input>" else path.with_suffix(".log"),
+        formatter=logzero.LogFormatter(fmt=DEFAULT_FILE_FORMAT, datefmt=DEFAULT_DATE_FORMAT),
+        maxBytes=DEFAULT_FILE_SIZE,
+        backupCount=DEFAULT_BACKUP_COUNT,
+        encoding="utf-8",
+        loglevel=DEFAULT_LEVEL,
+    )
+
+
+_default_file()
 
 
 def _set_file(
@@ -95,7 +103,23 @@ def _set_file(
     )
 
 
+def _enable_file(
+    self,
+    value: bool = True,
+):
+    if value:
+        _default_file()
+    else:
+        logzero.logfile(None)
+
+
+def _disable_file(self):
+    _enable_file(False)
+
+
 logger.set_file = MethodType(_set_file, logger)
+logger.enable_file = MethodType(_enable_file, logger)
+logger.disable_file = MethodType(_disable_file, logger)
 setattr(logger, "set_level", lambda level: logzero.loglevel(level))
 
 logger.CRITICAL = CRITICAL
